<?php

namespace ManiaLivePlugins\Flo\Menubar\Gui\Controls;

use ManiaLive\Gui\Windowing\Controls\Frame;
use ManiaLive\Gui\Toolkit\Layouts\Column;
use ManiaLive\Gui\Toolkit\Elements\Bgs1;
use ManiaLive\Gui\Toolkit\Elements\Icons128x128_1;
use ManiaLive\Gui\Toolkit\Elements\BgsPlayerCard;
use ManiaLive\Gui\Toolkit\Elements\Label;

class Item extends \ManiaLive\Gui\Windowing\Control
{
	private $label;
	private $background;
	private $container;
	private $subitems;
	private $name;
	private $icon;
	private $icon_style;
	private $action;
	
	function initializeComponents()
	{
		$this->sizeX = $this->getParam(0);
		$this->sizeY = $this->getParam(1);
		
		$this->action = array();
		$this->subitems = array();
		
		$this->container = new Frame();
		$layout = new Column();
		$layout->setDirection(Column::DIRECTION_UP);
		$this->container->applyLayout($layout);
		$this->addComponent($this->container);
		
		$this->background = new Bgs1();
		$this->background->setSize($this->getSizeX(), $this->getSizeY());
		$this->background->setSubStyle(Bgs1::NavButton);
		$this->addComponent($this->background);
		
		$this->icon = new Icons128x128_1();
		$this->icon->setVisibility(false);
		$this->icon->setValign('center');
		$this->addComponent($this->icon);
		
		$this->label = new Label();
		$this->addComponent($this->label);
	}
	
	function setAction($action)
	{
		$this->action = $action;
	}
	
	function onClick($login)
	{
		if (is_callable($this->action))
		{
			$this->getPlayerValue('active')->toggleSubitems($login);
			call_user_func_array($this->action, array($login));
		}
	}
	
	function beforeDraw()
	{
		$this->label->setValign('center');
		$this->label->setText($this->name);
		$this->label->setPositionY($this->getSizeY() / 2 - 0.2);
		
		if (!empty($this->subitems))
		{
			$this->label->setHalign('right');
			$this->label->setPositionX($this->getSizeX() - 2);
			$this->icon->setVisibility(true);
			$this->background->setAction($this->callback('toggleSubitems'));
			$this->background->setSubStyle(Bgs1::NavButton);
		}
		else
		{
			$this->label->setHalign('left');
			$this->label->setPositionX(1);
			$this->icon->setVisibility(false);
			$this->background->setAction($this->callback('onClick'));
			$this->background->setSubStyle(Bgs1::NavButtonBlink);
		}
		
		if ($this == $this->getPlayerValue('active') && !empty($this->subitems))
		{
			$this->background->setSubStyle(Bgs1::NavButtonBlink);
			$this->icon->setPosition(-3.5);
			$this->icon->setSize(7, 7);
		}
		elseif (!empty($this->subitems))
		{
			$this->background->setSubStyle(Bgs1::NavButton);
			$this->icon->setSize(4, 4);
			$this->icon->setPosition(1, $this->getSizeY() / 2);
		}
		
		$this->container->setPosition(-$this->getSizeX(), $this->getSizeY());
		$this->container->clearComponents();
		
		foreach ($this->subitems as $item)
		{
			$this->container->addComponent($item);
		}
	}
	
	function afterDraw() {}
	
	function setName($name)
	{
		$this->name = $name;
	}
	
	function getName()
	{
		return $this->name;
	}
	
	function setIcon($icon)
	{
		$this->icon->setVisibility(true);
		$this->icon->setSubstyle($icon);
	}
	
	function getIcon()
	{
		return $this->icon;
	}
	
	function toggleSubitems($login)
	{
		if ($this->getPlayerValue('active') !== null)
		{
			$this->getPlayerValue('active')->hideSubitems();
			if ($this->getPlayerValue('active') == $this)
			{
				$this->setPlayerValue('active', null);
				$this->getWindow()->show();
				return;
			}
		}

		$this->setPlayerValue('active', $this);
		$this->showSubitems();
		
		$this->getWindow()->show();
	}
	
	function hideSubitems()
	{
		foreach ($this->subitems as $item)
		{
			$item->setVisibility(false);
		}
	}
	
	function showSubitems()
	{
		foreach ($this->subitems as $item)
		{
			$item->setVisibility(true);
		}
	}
	
	function getItem($name)
	{
		if (isset($this->subitems[$name]))
		{
			return $this->subitems[$name];
		}
		else
		{
			return null;
		}
	}
	
	function addSubitem(Item $item)
	{
		$item->setVisibility(false);
		$this->subitems[$item->getName()] = $item;
	}
}

?>