<?php

namespace ManiaLivePlugins\Flo\Menubar;

use ManiaLive\Features\Admin\AdminGroup;
use ManiaLive\Config\Loader;
use ManiaLive\Gui\Windowing\Window;
use ManiaLivePlugins\Flo\Menubar\Gui\Controls\Item;
use ManiaLivePlugins\Flo\Menubar\Gui\Windows\Menu;
use ManiaLive\PluginHandler\Plugin;
use ManiaLivePlugins\Flo\TestPlugin;

class Menubar extends \ManiaLive\PluginHandler\Plugin
{
	static $menuroot;
	
	public function onInit()
	{
		self::$menuroot = array();
		$this->setVersion(1);
		$this->setPublicMethod('addButton');
		$this->setPublicMethod('setMenuIcon');
	}
	
	protected function createMenu($login)
	{
		$menu = Menu::Create($login);
		$menu->setRoot($this->buildMenu($login));
		$menu->setPosition(64.7, 26);
		$menu->setScale(0.8);
		$menu->show();
	}
	
	public function onReady()
	{
		$this->enableStorageEvents();
		
		// create menu for players
		foreach ($this->storage->players as $login => $player)
			$this->createMenu($login);
			
		// create menu for spectators
		foreach ($this->storage->spectators as $login => $player)
			$this->createMenu($login);
		
		// display menu if player connects
		$this->enableDedicatedEvents();
	}
	
	public function onPlayerConnect($login, $isSpectator)
	{
		// create menu for the player that just joined
		$this->createMenu($login);
	}
	
	protected function buildMenu($login)
	{
		$root = new Item(18, 4);
		$root->setName('Root');
		
		foreach (self::$menuroot as $items)
		{
			// if this item is displayed to admins only
			// and we're not displaying it to one, then skip
			if ($items[3] && !AdminGroup::contains($login)) continue;
			
			$node = $root;
			for ($i = 0; $i < count($items[0]); $i++)
			{
				$item = $node->getItem($items[0][$i]);
				if ($item == null)
				{
					$item = new Item(18, 4);
					$item->setName($items[0][$i]);
					
					$node->addSubitem($item);
					if ($i == 0) $item->setVisibility(true);
					$node = $item;
				}
				else
				{
					$node = $item;
				}
			}
			
			if ($items[1])
				$node->setIcon($items[1]);
				
			if ($items[2])
				$node->setAction($items[2]);
		}
		return $root;
	}
	
	/**
	 * 
	 * Enter description here ...
	 * @param unknown_type $plugin_name
	 * @param unknown_type $icon
	 */
	function setMenuIcon($plugin_name, $icon, $admin = false)
	{
		$plugin = explode('\\', $plugin_name);
		$items = array($plugin[1]);
		
		$node = array
		(
			$items,
			$icon,
			null,
			$admin
		);
		
		self::$menuroot[] = $node;
	}
	
	/**
	 * Create a submenu from a string seperated by a slash.
	 * First part is the plugin's name, second part is the button name describing
	 * the function that it will trigger.
	 * Example: MyPlugin/doSomething
	 * @param unknown_type $path
	 * @param unknown_type $icon
	 * @param unknown_type $action
	 */
	function addButton($plugin_name, $button_name, $icon = null, $action = null, $admin = false)
	{
		$plugin = explode('\\', $plugin_name);
		$items = array($plugin[1], $button_name);
		
		$node = array
		(
			$items,
			$icon,
			$action,
			$admin
		);
			
		self::$menuroot[] = $node;
	}
}

?>